JavaScriptEnvironmentUninitializedException class

Exception thrown when a JavaScript environment is uninitialized.

This is thrown when the JavaScript environment is no longer available because it has not been initialized.

Inheritance

Constructors

JavaScriptEnvironmentUninitializedException(String message)
Creates a new JavaScriptEnvironmentUninitializedException with the given message.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
message String
The message of the exception.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited