removeJavaScriptChannel abstract method
Removes the JavaScript channel with the matching name from the set of enabled channels for the context of the current JavaScript instance.
This disables the channel with the matching name if it was previously enabled through the addJavaScriptChannel.
Implementation
Future<void> removeJavaScriptChannel(String javaScriptChannelName);