JavaScriptEnvironmentUninitializedException class
Exception thrown when a JavaScript environment is uninitialized.
This is thrown when the JavaScript environment is no longer available because it has not been initialized.
- Inheritance
-
- Object
- JavaScriptPlatformException
- JavaScriptUnavailablePlatformException
- JavaScriptEnvironmentUninitializedException
Constructors
- JavaScriptEnvironmentUninitializedException(String message)
-
Creates a new JavaScriptEnvironmentUninitializedException with the given message.
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited